#
# spec file for package atlascpp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0_6-3
Name:           atlascpp
Version:        0.6.4
Release:        2.11
Summary:        Remote protocol for the Worldforge MMORPG system
License:        GPL-2.0-or-later AND LGPL-2.1-only
Group:          Development/Languages/C and C++
URL:            http://www.worldforge.org/index.php/components/atlas-cpp/
Source:         http://downloads.sourceforge.net/worldforge/Atlas-C++-%{version}.tar.bz2
BuildRequires:  gcc-c++
BuildRequires:  libbz2-devel
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

%description
This library implements the Atlas protocol for use in client-server
game applications. It is the standard implementation used by games written
by the WorldForge project.

%package -n lib%{name}-%{soname}
Summary:        Remote protocol for the Worldforge MMORPG system
Group:          System/Libraries
# libatlasccp-0.6.so.3 was wrongly packaged in libatlascpp-0_6-1
Conflicts:      libatlascpp-0_6-1 = 0.6.4

%description -n lib%{name}-%{soname}
This library implements the Atlas protocol for use in client-server
game applications. It is the standard implementation used by games written
by the WorldForge project. This library is suitable for linking to either
clients or servers.

%package devel
Summary:        Development files for the Atlas protocol C++ implementation
Group:          Development/Languages/C and C++
Requires:       lib%{name}-%{soname} = %{version}

%description devel
This library implements the Atlas protocol for use in client-server
game applications. It is the standard implementation used by games written
by the WorldForge project. This library is suitable for linking to either
clients or servers.

%prep
%setup -q -n Atlas-C++-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CPPFLAGS="$CFLAGS"
%configure
make %{?_smp_mflags}

%install
%makeinstall

# Do not package libtool archives.
rm %{buildroot}%{_libdir}/lib*.la

%post -n lib%{name}-%{soname} -p /sbin/ldconfig

%postun -n lib%{name}-%{soname} -p /sbin/ldconfig

%files -n lib%{name}-%{soname}
%doc AUTHORS
%license COPYING
%{_libdir}/lib*.so.*

%files devel
%doc NEWS README THANKS ChangeLog TODO HACKING ROADMAP
%{_bindir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%changelog
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Rename libatlascpp-0_6-1 subpackage to libatlascpp-0_6-3, making
  the package name match the libraries provided.
* Mon Jun 18 2018 antoine.belvire@opensuse.org
- Update to version 0.6.4:
  * Use same real value comparison as WFMath.
  * Remove checking new pointer.
  * Remove unused string.
  * Use epsilon for float comparison.
  * Replace deprecated INCLUDES with AM_CPPFLAGS.
- Drop unneeded patches:
  * atlascpp-0.6.2-Werror.patch: Current version builds just fine
    with -Werror, so let's keep it.
  * fsf.patch: FSF postal address was updated by upstream in every
    header and in COPYING.
- Fix license: LGPL-2.1-only (according to COPYING file) and
  GPL-2.0-or-later (according to some file headers).
* Sun Oct 30 2016 jengelh@inai.de
- Update RPM groups, summary and descriptions.
* Wed Oct 12 2016 mailaender@opensuse.org
- Don't package libtool archives.
- Add fsf.patch to fix the FSF address in the license file.
* Thu Feb 27 2014 joop.boonen@opensuse.org
- Build version 0.6.3
* Tue May 22 2012 joop.boonen@opensuse.org
- Build version 0.6.2 using the provided spec file as a template
